@@ -4,13 +4,22 @@ from __future__ import annotations
 
 from typing import List, Optional, Union, cast
 
-import spl.token.instructions as spl_token
-from solana.blockhash import Blockhash
-from solana.keypair import Keypair
-from solana.publickey import PublicKey
 from solana.rpc.api import Client
 from solana.rpc.commitment import Commitment
-from solana.rpc.types import RPCResponse, TxOpts
+from solana.rpc.types import TxOpts
+from solders.hash import Hash as Blockhash
+from solders.keypair import Keypair
+from solders.pubkey import Pubkey
+from solders.rpc.responses import (
+    GetTokenAccountBalanceResp,
+    GetTokenAccountsByDelegateJsonParsedResp,
+    GetTokenAccountsByDelegateResp,
+    GetTokenAccountsByOwnerJsonParsedResp,
+    GetTokenAccountsByOwnerResp,
+    SendTransactionResp,
+)
+
+import spl.token.instructions as spl_token
 from spl.token._layouts import ACCOUNT_LAYOUT, MINT_LAYOUT, MULTISIG_LAYOUT
 from spl.token.core import AccountInfo, MintInfo, _TokenCore
 
@@ -18,7 +27,7 @@ from spl.token.core import AccountInfo, MintInfo, _TokenCore
 class Token(_TokenCore):  # pylint: disable=too-many-public-methods
     """An ERC20-like Token."""
 
-    def __init__(self, conn: Client, pubkey: PublicKey, program_id: PublicKey, payer: Keypair) -> None:
+    def __init__(self, conn: Client, pubkey: Pubkey, program_id: Pubkey, payer: Keypair) -> None:
         """Initialize a client to a SPL-Token program."""
         super().__init__(pubkey, program_id, payer)
         self._conn = conn
@@ -34,7 +43,7 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             Number of lamports required.
         """
         resp = conn.get_minimum_balance_for_rent_exemption(ACCOUNT_LAYOUT.sizeof())
-        return resp["result"]
+        return resp.value
 
     @staticmethod
     def get_min_balance_rent_for_exempt_for_mint(conn: Client) -> int:
@@ -47,7 +56,7 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             Number of lamports required.
         """
         resp = conn.get_minimum_balance_for_rent_exemption(MINT_LAYOUT.sizeof())
-        return resp["result"]
+        return resp.value
 
     @staticmethod
     def get_min_balance_rent_for_exempt_for_multisig(conn: Client) -> int:
@@ -59,22 +68,39 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         Return: Number of lamports required.
         """
         resp = conn.get_minimum_balance_for_rent_exemption(MULTISIG_LAYOUT.sizeof())
-        return resp["result"]
+        return resp.value
 
-    def get_accounts(
+    def get_accounts_by_owner(
         self,
-        owner: PublicKey,
-        is_delegate: bool = False,
+        owner: Pubkey,
         commitment: Optional[Commitment] = None,
-        encoding: str = "jsonParsed",
-    ) -> RPCResponse:
-        """Get token accounts of the provided owner by the token's mint.
+        encoding: str = "base64",
+    ) -> GetTokenAccountsByOwnerResp:
+        """Get token accounts of the provided owner.
+
+        Args:
+            owner: Public Key of the token account owner.
+            commitment: (optional) Bank state to query.
+            encoding: (optional) Encoding for Account data, either "base58" (slow) or "base64".
+        """
+        args = self._get_accounts_args(
+            owner,
+            commitment,
+            encoding,
+            self._conn.commitment,  # pylint: disable=protected-access
+        )
+        return self._conn.get_token_accounts_by_owner(*args)
+
+    def get_accounts_by_owner_json_parsed(
+        self,
+        owner: Pubkey,
+        commitment: Optional[Commitment] = None,
+    ) -> GetTokenAccountsByOwnerJsonParsedResp:
+        """Get token accounts of the provided owner by the token's mint, in JSON format.
 
         Args:
             owner: Public Key of the token account owner.
-            is_delegate: (optional) Flag specifying if the `owner` public key is a delegate.
             commitment: (optional) Bank state to query.
-            encoding: (optional) Encoding for Account data, either "base58" (slow), "base64" or jsonParsed".
 
 
         Parsed-JSON encoding attempts to use program-specific state parsers to return more
@@ -83,15 +109,61 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         from results. jsonParsed encoding is UNSTABLE.
         """
         args = self._get_accounts_args(
-            owner, commitment, encoding, self._conn._commitment  # pylint: disable=protected-access
-        )
-        return (
-            self._conn.get_token_accounts_by_delegate(*args)
-            if is_delegate
-            else self._conn.get_token_accounts_by_owner(*args)
+            owner,
+            commitment,
+            "jsonParsed",
+            self._conn.commitment,  # pylint: disable=protected-access
         )
+        return self._conn.get_token_accounts_by_owner_json_parsed(*args)
 
-    def get_balance(self, pubkey: PublicKey, commitment: Optional[Commitment] = None) -> RPCResponse:
+    def get_accounts_by_delegate(
+        self,
+        owner: Pubkey,
+        commitment: Optional[Commitment] = None,
+        encoding: str = "base64",
+    ) -> GetTokenAccountsByDelegateResp:
+        """Get token accounts of the provided delegate.
+
+        Args:
+            owner: Public Key of the delegate account.
+            commitment: (optional) Bank state to query.
+            encoding: (optional) Encoding for Account data, either "base58" (slow) or "base64".
+        """
+        args = self._get_accounts_args(
+            owner,
+            commitment,
+            encoding,
+            self._conn.commitment,  # pylint: disable=protected-access
+        )
+        return self._conn.get_token_accounts_by_delegate(*args)
+
+    def get_accounts_by_delegate_json_parsed(
+        self,
+        owner: Pubkey,
+        commitment: Optional[Commitment] = None,
+        encoding: str = "base64",
+    ) -> GetTokenAccountsByDelegateJsonParsedResp:
+        """Get token accounts of the provided delegate, in JSON format.
+
+        Args:
+            owner: Public Key of the delegate account.
+            commitment: (optional) Bank state to query.
+            encoding: (optional) Encoding for Account data, either "base58" (slow) or "base64".
+
+        Parsed-JSON encoding attempts to use program-specific state parsers to return more
+        human-readable and explicit account state data. If parsed-JSON is requested but a
+        valid mint cannot be found for a particular account, that account will be filtered out
+        from results. jsonParsed encoding is UNSTABLE.
+        """
+        args = self._get_accounts_args(
+            owner,
+            commitment,
+            encoding,
+            self._conn.commitment,  # pylint: disable=protected-access
+        )
+        return self._conn.get_token_accounts_by_delegate_json_parsed(*args)
+
+    def get_balance(self, pubkey: Pubkey, commitment: Optional[Commitment] = None) -> GetTokenAccountBalanceResp:
         """Get the balance of the provided token account.
 
         Args:
@@ -105,10 +177,10 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         cls,
         conn: Client,
         payer: Keypair,
-        mint_authority: PublicKey,
+        mint_authority: Pubkey,
         decimals: int,
-        program_id: PublicKey,
-        freeze_authority: Optional[PublicKey] = None,
+        program_id: Pubkey,
+        freeze_authority: Optional[Pubkey] = None,
         skip_confirmation: bool = False,
         recent_blockhash: Optional[Blockhash] = None,
     ) -> Token:
@@ -134,7 +206,16 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         balance_needed = Token.get_min_balance_rent_for_exempt_for_mint(conn)
         # Construct transaction
         token, txn, payer, mint_account, opts = _TokenCore._create_mint_args(
-            conn, payer, mint_authority, decimals, program_id, freeze_authority, skip_confirmation, balance_needed, cls
+            conn,
+            payer,
+            mint_authority,
+            decimals,
+            program_id,
+            freeze_authority,
+            skip_confirmation,
+            balance_needed,
+            cls,
+            conn.commitment,
         )
         # Send the two instructions
         conn.send_transaction(txn, payer, mint_account, opts=opts, recent_blockhash=recent_blockhash)
@@ -142,16 +223,15 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
 
     def create_account(
         self,
-        owner: PublicKey,
+        owner: Pubkey,
         skip_confirmation: bool = False,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> PublicKey:
+    ) -> Pubkey:
         """Create and initialize a new account.
 
         This account may then be used as a `transfer()` or `approve()` destination.
 
         Args:
-
             owner: User account that will own the new account.
             skip_confirmation: (optional) Option to skip transaction confirmation.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
@@ -164,7 +244,7 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         """
         balance_needed = Token.get_min_balance_rent_for_exempt_for_account(self._conn)
         new_account_pk, txn, payer, new_account, opts = self._create_account_args(
-            owner, skip_confirmation, balance_needed
+            owner, skip_confirmation, balance_needed, self._conn.commitment
         )
         # Send the two instructions
         self._conn.send_transaction(txn, payer, new_account, opts=opts, recent_blockhash=recent_blockhash)
@@ -172,14 +252,13 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
 
     def create_associated_token_account(
         self,
-        owner: PublicKey,
+        owner: Pubkey,
         skip_confirmation: bool = False,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> PublicKey:
+    ) -> Pubkey:
         """Create an associated token account.
 
         Args:
-
             owner: User account that will own the associated token account.
             skip_confirmation: (optional) Option to skip transaction confirmation.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
@@ -191,24 +270,25 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         or until the transaction is confirmed.
         """
         # Construct transaction
-        public_key, txn, payer, opts = self._create_associated_token_account_args(owner, skip_confirmation)
+        public_key, txn, payer, opts = self._create_associated_token_account_args(
+            owner, skip_confirmation, self._conn.commitment
+        )
         self._conn.send_transaction(txn, payer, opts=opts, recent_blockhash=recent_blockhash)
         return public_key
 
     @staticmethod
     def create_wrapped_native_account(
         conn: Client,
-        program_id: PublicKey,
-        owner: PublicKey,
+        program_id: Pubkey,
+        owner: Pubkey,
         payer: Keypair,
         amount: int,
         skip_confirmation: bool = False,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> PublicKey:
+    ) -> Pubkey:
         """Create and initialize a new account on the special native token mint.
 
         Args:
-
             conn: RPC connection to a solana cluster.
             program_id: SPL Token program account.
             owner: The owner of the new token account.
@@ -225,8 +305,14 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         """
         # Allocate memory for the account
         balance_needed = Token.get_min_balance_rent_for_exempt_for_account(conn)
-        new_account_public_key, txn, payer, new_account, opts = _TokenCore._create_wrapped_native_account_args(
-            program_id, owner, payer, amount, skip_confirmation, balance_needed
+        (new_account_public_key, txn, payer, new_account, opts,) = _TokenCore._create_wrapped_native_account_args(
+            program_id,
+            owner,
+            payer,
+            amount,
+            skip_confirmation,
+            balance_needed,
+            conn.commitment,
         )
         conn.send_transaction(txn, payer, new_account, opts=opts, recent_blockhash=recent_blockhash)
         return new_account_public_key
@@ -234,15 +320,16 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
     def create_multisig(
         self,
         m: int,
-        multi_signers: List[PublicKey],
-        opts: TxOpts = TxOpts(skip_preflight=True, skip_confirmation=False),
+        multi_signers: List[Pubkey],
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> PublicKey:  # pylint: disable=invalid-name
+    ) -> Pubkey:  # pylint: disable=invalid-name
         """Create and initialize a new multisig.
 
         Args:
             m: Number of required signatures.
             multi_signers: Full set of signers.
+            opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
 
         Returns:
@@ -250,29 +337,30 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         """
         balance_needed = Token.get_min_balance_rent_for_exempt_for_multisig(self._conn)
         txn, payer, multisig = self._create_multisig_args(m, multi_signers, balance_needed)
-        self._conn.send_transaction(txn, payer, multisig, opts=opts, recent_blockhash=recent_blockhash)
-        return multisig.public_key
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        self._conn.send_transaction(txn, payer, multisig, opts=opts_to_use, recent_blockhash=recent_blockhash)
+        return multisig.pubkey()
 
     def get_mint_info(self) -> MintInfo:
         """Retrieve mint information."""
         info = self._conn.get_account_info(self.pubkey)
         return self._create_mint_info(info)
 
-    def get_account_info(self, account: PublicKey, commitment: Optional[Commitment] = None) -> AccountInfo:
+    def get_account_info(self, account: Pubkey, commitment: Optional[Commitment] = None) -> AccountInfo:
         """Retrieve account information."""
         info = self._conn.get_account_info(account, commitment)
         return self._create_account_info(info)
 
     def transfer(
         self,
-        source: PublicKey,
-        dest: PublicKey,
-        owner: Union[Keypair, PublicKey],
+        source: Pubkey,
+        dest: Pubkey,
+        owner: Union[Keypair, Pubkey],
         amount: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Transfer tokens to another account.
 
         Args:
@@ -284,19 +372,20 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._transfer_args(source, dest, owner, amount, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._transfer_args(source, dest, owner, amount, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def approve(
         self,
-        source: PublicKey,
-        delegate: PublicKey,
-        owner: PublicKey,
+        source: Pubkey,
+        delegate: Pubkey,
+        owner: Pubkey,
         amount: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Grant a third-party permission to transfer up the specified number of tokens from an account.
 
         Args:
@@ -308,17 +397,18 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, payer, signers, opts = self._approve_args(source, delegate, owner, amount, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, payer, signers, opts = self._approve_args(source, delegate, owner, amount, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, payer, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def revoke(
         self,
-        account: PublicKey,
-        owner: PublicKey,
+        account: Pubkey,
+        owner: Pubkey,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Revoke transfer authority for a given account.
 
         Args:
@@ -328,19 +418,20 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, payer, signers, opts = self._revoke_args(account, owner, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, payer, signers, opts = self._revoke_args(account, owner, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, payer, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def set_authority(
         self,
-        account: PublicKey,
-        current_authority: Union[Keypair, PublicKey],
+        account: Pubkey,
+        current_authority: Union[Keypair, Pubkey],
         authority_type: spl_token.AuthorityType,
-        new_authority: Optional[PublicKey] = None,
+        new_authority: Optional[Pubkey] = None,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Assign a new authority to the account.
 
         Args:
@@ -352,20 +443,26 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
         txn, payer, signers, opts = self._set_authority_args(
-            account, current_authority, authority_type, new_authority, multi_signers, opts
+            account,
+            current_authority,
+            authority_type,
+            new_authority,
+            multi_signers,
+            opts_to_use,
         )
         return self._conn.send_transaction(txn, payer, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def mint_to(
         self,
-        dest: PublicKey,
-        mint_authority: Union[Keypair, PublicKey],
+        dest: Pubkey,
+        mint_authority: Union[Keypair, Pubkey],
         amount: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Mint new tokens.
 
         Args:
@@ -379,18 +476,19 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
         If skip confirmation is set to `False`, this method will block for at most 30 seconds
         or until the transaction is confirmed.
         """
-        txn, signers, opts = self._mint_to_args(dest, mint_authority, amount, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._mint_to_args(dest, mint_authority, amount, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def burn(
         self,
-        account: PublicKey,
-        owner: PublicKey,
+        account: Pubkey,
+        owner: Pubkey,
         amount: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Burn tokens.
 
         Args:
@@ -401,18 +499,19 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._burn_args(account, owner, amount, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._burn_args(account, owner, amount, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def close_account(
         self,
-        account: PublicKey,
-        dest: PublicKey,
-        authority: Union[Keypair, PublicKey],
+        account: Pubkey,
+        dest: Pubkey,
+        authority: Union[Keypair, Pubkey],
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Remove approval for the transfer of any remaining tokens.
 
         Args:
@@ -423,17 +522,18 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._close_account_args(account, dest, authority, multi_signers)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._close_account_args(account, dest, authority, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def freeze_account(
         self,
-        account: PublicKey,
-        authority: Union[PublicKey, Keypair],
+        account: Pubkey,
+        authority: Union[Pubkey, Keypair],
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Freeze account.
 
         Args:
@@ -443,17 +543,18 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._freeze_account_args(account, authority, multi_signers)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._freeze_account_args(account, authority, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def thaw_account(
         self,
-        account: PublicKey,
-        authority: PublicKey,
+        account: Pubkey,
+        authority: Pubkey,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Thaw account.
 
         Args:
@@ -463,20 +564,21 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._thaw_account_args(account, authority, multi_signers)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._thaw_account_args(account, authority, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def transfer_checked(
         self,
-        source: PublicKey,
-        dest: PublicKey,
-        owner: Union[Keypair, PublicKey],
+        source: Pubkey,
+        dest: Pubkey,
+        owner: Union[Keypair, Pubkey],
         amount: int,
         decimals: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Transfer tokens to another account, asserting the token mint and decimals.
 
         Args:
@@ -489,20 +591,23 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._transfer_checked_args(source, dest, owner, amount, decimals, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._transfer_checked_args(
+            source, dest, owner, amount, decimals, multi_signers, opts_to_use
+        )
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def approve_checked(
         self,
-        source: PublicKey,
-        delegate: PublicKey,
-        owner: PublicKey,
+        source: Pubkey,
+        delegate: Pubkey,
+        owner: Pubkey,
         amount: int,
         decimals: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Grant a third-party permission to transfer up the specified number of tokens from an account.
 
         This method also asserts the token mint and decimals.
@@ -517,21 +622,22 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
         txn, payer, signers, opts = self._approve_checked_args(
-            source, delegate, owner, amount, decimals, multi_signers, opts
+            source, delegate, owner, amount, decimals, multi_signers, opts_to_use
         )
         return self._conn.send_transaction(txn, payer, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def mint_to_checked(
         self,
-        dest: PublicKey,
-        mint_authority: Union[Keypair, PublicKey],
+        dest: Pubkey,
+        mint_authority: Union[Keypair, Pubkey],
         amount: int,
         decimals: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Mint new tokens, asserting the token mint and decimals.
 
         Args:
@@ -543,19 +649,22 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._mint_to_checked_args(dest, mint_authority, amount, decimals, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._mint_to_checked_args(
+            dest, mint_authority, amount, decimals, multi_signers, opts_to_use
+        )
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
 
     def burn_checked(
         self,
-        account: PublicKey,
-        owner: Union[Keypair, PublicKey],
+        account: Pubkey,
+        owner: Union[Keypair, Pubkey],
         amount: int,
         decimals: int,
         multi_signers: Optional[List[Keypair]] = None,
-        opts: TxOpts = TxOpts(),
+        opts: Optional[TxOpts] = None,
         recent_blockhash: Optional[Blockhash] = None,
-    ) -> RPCResponse:
+    ) -> SendTransactionResp:
         """Burn tokens, asserting the token mint and decimals.
 
         Args:
@@ -567,5 +676,6 @@ class Token(_TokenCore):  # pylint: disable=too-many-public-methods
             opts: (optional) Transaction options.
             recent_blockhash: (optional) a prefetched Blockhash for the transaction.
         """
-        txn, signers, opts = self._burn_checked_args(account, owner, amount, decimals, multi_signers, opts)
+        opts_to_use = TxOpts(preflight_commitment=self._conn.commitment) if opts is None else opts
+        txn, signers, opts = self._burn_checked_args(account, owner, amount, decimals, multi_signers, opts_to_use)
         return self._conn.send_transaction(txn, *signers, opts=opts, recent_blockhash=recent_blockhash)
